#!/usr/bin/python
# -*- coding: utf-8 -*-
# DOC: http://docs.python.org/library/pprint.html
#      http://docs.python.org/library/pickle.html
"""
Use to de-serialize pickle object.

Usage:
    history2stdout.py /path/to/pickle.pkl

"""

import pickle, pprint, sys, string
import time

from os.path import basename
from operator import itemgetter

class Track(object):#{{{
    """
    Track object
    """

    def __init__(self, file=None, time=0, **kwargs):#{{{
        self.title = self.artist = self.album = ''
        self._file = file
        self.time = time
        self.__dict__.update(**kwargs)
        # Needed for multipule tags which returns a list instead of a string
        #  have tags been collapsed?
        self.collapse_tags_bool = False
        self.collapse_tags()#}}}

    def collapse_tags(self):#{{{
        """
        Necessary to deal with tags defined multiple times.
        """
        for tag, value in self.__dict__.iteritems():
            if isinstance(value, list):
                #self.__dict__[tag] = ", ".join(set(value))
                self.collapse_tags_bool = True
                self.__dict__.update({tag: ", ".join(set(value))})
                #print value#}}}

    def get_artist(self):#{{{
        """return lowercase UNICODE name of artist"""
        #return unicode(self.artist.lower(), 'utf-8')
        return unicode(self.artist, 'utf-8')

    def get_title(self):
        """return lowercase UNICODE title of song"""
        return unicode(self.title, 'utf-8')

    def get_album(self):
        """return lowercase UNICODE album of song"""
        return unicode(self.album, 'utf-8')
    
    def get_filename(self):
        return unicode(self.file, 'utf-8')#}}}

    def __repr__(self):#{{{
        return '<%s: %s - %s - %s (%s)>' % (
            self.__class__.__name__,
            self.album,
            self.artist,
            self.title,
            self.duration,
        )

    def __int__(self):
        return self.time

    def __add__(self, other):
        return Track(time=self.time + other.time)

    def __sub__(self, other):
        return Track(time=self.time - other.time)

    def __hash__(self):
        if self.file:
            return hash(self.file)
        else:
            return id(self)

    def __eq__(self, other):
        return hash(self) == hash(other)

    def __ne__(self, other):
        return hash(self) != hash(other)

    @property
    def file(self):
        """file is an immutable attribute that's used for the hash method"""
        return self._file

    def get_time(self):
        return self._time

    def set_time(self, value):
        self._time = int(value)

    time = property(get_time, set_time, doc='song duration in seconds')

    @property
    def duration(self):
        t = time.gmtime(int(self.time))
        if t.tm_hour:
            fmt = '%H:%M:%S'
        else:
            fmt = '%M:%S'
        return time.strftime(fmt, t)#}}}
#}}}

# Open pickled file
pkl_file = open(sys.argv[1], 'rb')
dict = pickle.load(pkl_file)

if basename(sys.argv[1]) == 'similar_cache.pkl':
    cache_date = pickle.load(pkl_file)
    #print 'Date of creation of cache : %s\n' % cache_date['DATE']

# closes
pkl_file.close()

# Raw output, python object as is (dictionary in case of history)
#pprint.pprint(dict, indent=4, depth=1)
#pprint.pprint(dict)
#sys.exit()
# formatted output:
# [artist]
# file A
# file B
# ...
if basename(sys.argv[1]) == 'similar_cache.pkl':
    for k in dict:
        print '\n[%s]' % k
        items = dict[k]
        #print dict
        #print items
        #print string.join(dict[k], ' / ')
        liste = []
        for art in items:
            liste.append(str("%s : %1.2f" % (art[0], art[1])))
        print string.join(liste, ' / ')
else:
    for track in  dict:
        print track.get_artist() + ' - ' + track.get_title()
    print '\r'




sys.exit()

# VIM MODLINE (not mandatory) {{{2
# vim: ts=4 expandtab sw=4 encoding=utf8 nowrap fo=rcqo fdl=1 fdm=marker
# vim: textwidth=79
# 2}}}
